@@ -1,6 +1,6 @@
 import braintree
-from braintree.client_token import ClientToken
 from braintree.resource import Resource
+from braintree.client_token import ClientToken
 from braintree import exceptions
 
 class ClientTokenGateway(object):
@@ -9,10 +9,17 @@ class ClientTokenGateway(object):
         self.config = gateway.config
 
 
-    def generate(self, params):
-        if params:
-            Resource.verify_keys(params, ClientToken.generate_signature())
-            params = {'client_token': params}
+    def generate(self, params={}):
+        if "options" in params and not "customer_id" in params:
+            for option in ["verify_card", "make_default", "fail_on_duplicate_payment_method"]:
+                if option in params["options"]:
+                    raise exceptions.InvalidSignatureError("cannot specify %s without a customer_id" % option)
+
+        if "version" not in params:
+            params["version"] = 2
+
+        Resource.verify_keys(params, ClientToken.generate_signature())
+        params = {'client_token': params}
 
         response = self.config.http().post(self.config.base_merchant_path() + "/client_token", params)
 
