@@ -511,6 +511,11 @@ class ErrorCodes(object):
         ThreeDSecureAuthenticationFailed = "81571"
         ThreeDSecureTokenIsInvalid = "91568"
         ThreeDSecureTransactionDataDoesntMatchVerify = "91570"
+        ThreeDSecureEciFlagIsRequired = "915113"
+        ThreeDSecureCavvIsRequired = "915116"
+        ThreeDSecureXidIsRequired = "915115"
+        ThreeDSecureEciFlagIsInvalid = "915114"
+        ThreeDSecureMerchantAccountDoesNotSupportCardType = "915131"
         TypeIsInvalid = "91523"
         TypeIsRequired = "91524"
         UnsupportedVoiceAuthorization = "91539"
